.. _global_coefficient_requests:

Global coefficients
===================

.. py:module:: ansys.simai.core.data.global_coefficients_requests

This module contains a collection of classes for validating global coefficient formulas and
executing them on project samples.

ProcessGlobalCoefficient
------------------------

.. autoclass:: ProcessGlobalCoefficient()
    :members:

ProcessGlobalCoefficientDirectory
---------------------------------

.. autoclass:: ProcessGlobalCoefficientDirectory()
    :members:
